#
# spec file for package python-yaql
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global oldpython python
Name:           python-yaql
Version:        2.0.0
Release:        2.4
Summary:        YAQL - Yet Another Query Language
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/yaql
Source0:        https://files.pythonhosted.org/packages/source/y/yaql/yaql-2.0.0.tar.gz
BuildRequires:  openstack-macros
# for testing
BuildRequires:  python3-Sphinx
BuildRequires:  python3-fixtures
BuildRequires:  python3-pbr
BuildRequires:  python3-ply
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-python-subunit
BuildRequires:  python3-testrepository
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
YAQL (Yet Another Query Language) is an embeddable and extensible query
language, that allows performing complex queries against arbitrary objects. It
has a vast and comprehensive standard library of frequently used querying
functions and can be extend even further with user-specified functions. YAQL is
written in python and is distributed via PyPI.

%package -n python3-yaql
Summary:        YAQL - Yet Another Query Language
Requires:       python3-Babel
Requires:       python3-ply
Requires:       python3-python-dateutil
Conflicts:      %{oldpython}-yaql < %version-%release

%description -n python3-yaql
YAQL (Yet Another Query Language) is an embeddable and extensible query
language, that allows performing complex queries against arbitrary objects. It
has a vast and comprehensive standard library of frequently used querying
functions and can be extend even further with user-specified functions. YAQL is
written in python and is distributed via PyPI.

This package contains the Python 3.x module.

%prep
%autosetup -p1 -n yaql-2.0.0
%py_req_cleanup

%build
%{py3_build}

%install
%{py3_install}

%check
PYTHON=python3 python3 setup.py testr

%files -n python3-yaql
%license LICENSE
%doc ChangeLog README.rst
%{_bindir}/yaql
%{python3_sitelib}/yaql
%{python3_sitelib}/yaql*.egg-info

%changelog
* Fri Oct 14 2022 pgajdos@suse.com
- does not require python-six
* Mon Dec  6 2021 cloud-devel@suse.de
- removed 0b006f07226138ef26ab8296494f1dc1c09908e2.patch
- update to version 2.0.0
  - Fix hacking min version to 3.0.1
  - Make the CLI YAQL engine entirely configurable
  - OpenDev Migration Patch
  - Use __slots__ for more yaqltypes
  - Import docs building job
  - Dropping the py35 testing
  - [ussuri][goal] Drop python 2.7 support and testing
  - add python 3.7 unit test job
  - Get rid of Babel dependency since it is not needed
  - Add Python 3 Train unit tests
  - Update the documention for doc migration
  - Removed older version of python added 3.5/3.6
  - add python 3.6 unit test job
  - Replace assertItemsEqual with assertCountEqual
  - import zuul job settings from project-config
  - Update min tox version to 2.0
  - tox: Set 'ignore_basepython_conflict'
  - Make changes to groupBy() backward-compatible
  - Update hacking for Python3
  - Cleanup py27 support
  - Fix docs gate
  - Remove six
  - Switch to newer openstackdocstheme and reno versions
  - Stop to use the __future__ module.
  - Switch to collections.abc.*
  - fix tox python3 overrides
  - Fix readme Pygments package not found
  - Remove setting of version/release from releasenotes
* Mon May  3 2021 Dirk Müller <dmueller@suse.com>
- switch to wallaby template
* Tue Feb 16 2021 Dirk Müller <dmueller@suse.com>
- add 0b006f07226138ef26ab8296494f1dc1c09908e2.patch
* Thu Jun  4 2020 Dirk Mueller <dmueller@suse.com>
- remove oslosphinx dependency
* Tue May 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to stable/ussuri template (drops python 2.x support)
* Wed Oct  9 2019 Thomas Bechtold <tbechtold@suse.com>
- Cleanup specfile
* Mon Apr  8 2019 Dirk Mueller <dmueller@suse.com>
- switch to stable/stein spec template
* Mon Sep  3 2018 dmueller@suse.com
- switch to stable/rocky spec template
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Sat Aug  5 2017 tbechtold@suse.com
- switch to stable/pike version
* Wed Jun  7 2017 cloud-devel@suse.de
- update to version 1.1.3
  - Refactor datetime.datetime usage to defined DATETIME_TYPE
  - Use reno for releasenotes
  - [docs] Docstrings for branching YAQL functions
  - YAQL autodoc script
  - [docs] Docstrings for strings YAQL functions
  - Pass re.VERBOSE explicitly
  - [docs] Docstrings for queries YAQL functions
  - Added engine options to disable input/output data conversion
  - Use __slots__ for yaqltypes
  - [docs] Docstrings for system YAQL functions
  - [docs] Docstrings for common YAQL functions
  - Remove oslosphinx from sphinx extensions
  - Auto building of std library docs
  - Add help info to CLI options
  - Update tests of YAQL queries
  - Rename shiftBitsLeft and shiftBitsRight arguments
  - Don't include openstack/common in flake8 exclude list
  - Customizing and extending yaql documentation
  - Fix "indexOf", "lastIndexOf" methods length parameter usage
  - YAQL syntax documentation
  - Use modern PBR and hacking packages
  - Use __slots__ for Parameter/Function definition
  - Remove discover from test-requirements
  - [docs] Docstrings for date_time YAQL functions
  - [docs] Docstrings for legacy YAQL functions
  - [docs] Docstrings for math YAQL functions
  - Update flake8 ignore list
  - Improvements to yaql CLI
  - [docs] Docstrings for boolean YAQL functions
  - Add a test proving escaped back references work
  - groupBy() aggregator was fixed
  - Create child context in regex/search function
  - Drop MANIFEST.in - it's not needed by pbr
  - [docs] Docstrings for yaqlized YAQL functions
  - [docs] Docstrings for regex YAQL functions
  - Changed the home-page link
  - Replace ValueError with StopIteration in single() method
  - Use six.moves.input for Python 3 compatability
  - Enable release notes translation
  - [docs] Docstrings for collections YAQL functions
* Fri Feb 10 2017 tbechtold@suse.com
- Use spec from openstack/rpm-packaging project
- Add _service
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.1.1:
  * Fix string operators >= and <=
  * Extend .slice() method implementation to all Iterables
  * Fix typo in YAML example
  * Python 3 compatibility issues were fixed
* Thu May 26 2016 tbechtold@suse.com
- Initial packaging (version 1.1.0)
